@@ -4,16 +4,19 @@ QA/QC CLI entry points.
 """
 import click
 import logging
+import numpy as np
 import os
 import pprint
-from rex.utilities.cli_dtypes import STR, STRLIST, INT
+from rex.utilities.cli_dtypes import STR, STRLIST, INT, FLOAT
 from rex.utilities.execution import SLURM
 from rex.utilities.loggers import init_logger, init_mult
+from rex.utilities.utilities import dict_str_load
 
 from reV.config.qa_qc_config import QaQcConfig
 from reV.pipeline.status import Status
 from reV.qa_qc.qa_qc import QaQc
-from reV.qa_qc.summary import Summarize, SummaryPlots
+from reV.qa_qc.summary import (SummarizeH5, SummarizeSupplyCurve,
+                               SupplyCurvePlot, ExclusionsMask)
 
 logger = logging.getLogger(__name__)
 
@@ -71,8 +74,8 @@ def h5(ctx, h5_file, dsets, group, process_size, max_workers):
     """
     Summarize datasets in .h5 file
     """
-    Summarize.run(h5_file, ctx.obj['OUT_DIR'], group=group, dsets=dsets,
-                  process_size=process_size, max_workers=max_workers)
+    SummarizeH5.run(h5_file, ctx.obj['OUT_DIR'], group=group, dsets=dsets,
+                    process_size=process_size, max_workers=max_workers)
 
 
 @summarize.command()
@@ -87,7 +90,7 @@ def scatter_plots(ctx, plot_type, cmap):
     """
     create scatter plots from h5 summary tables
     """
-    QaQc._scatter_plots(ctx.obj['OUT_DIR'], plot_type, cmap)
+    QaQc.create_scatter_plots(ctx.obj['OUT_DIR'], plot_type, cmap)
 
 
 @summarize.command()
@@ -102,7 +105,7 @@ def supply_curve_table(ctx, sc_table, columns):
     Summarize Supply Curve Table
     """
     ctx.obj['SC_TABLE'] = sc_table
-    Summarize.supply_curve(sc_table, ctx.obj['OUT_DIR'], columns=columns)
+    SummarizeSupplyCurve.run(sc_table, ctx.obj['OUT_DIR'], columns=columns)
 
 
 @summarize.command()
@@ -123,8 +126,31 @@ def supply_curve_plot(ctx, sc_table, plot_type, lcoe):
     if sc_table is None:
         sc_table = ctx.obj['SC_TABLE']
 
-    SummaryPlots.supply_curve(sc_table, ctx.obj['OUT_DIR'],
-                              plot_type=plot_type, lcoe=lcoe)
+    SupplyCurvePlot.plot(sc_table, ctx.obj['OUT_DIR'],
+                         plot_type=plot_type, lcoe=lcoe)
+
+
+@summarize.command()
+@click.option('--excl_mask', '-mask', type=click.Path(exists=True),
+              required=True,
+              help='Path to .npy file containing final exclusions mask')
+@click.option('--plot_type', '-plt', default='plotly',
+              type=click.Choice(['plot', 'plotly'], case_sensitive=False),
+              help=(" plot_type of plot to create 'plot' or 'plotly', by "
+                    "default 'plot'"))
+@click.option('--cmap', '-cmap', type=str, default='viridis',
+              help="Colormap name, by default 'viridis'")
+@click.option('--plot_step', '-step', type=int, default=100,
+              help="Step between points to plot")
+@click.pass_context
+def exclusions_mask(ctx, excl_mask, plot_type, cmap, plot_step):
+    """
+    create heat map of exclusions mask
+    """
+    excl_mask = np.load(excl_mask)
+    ExclusionsMask.plot(excl_mask, ctx.obj['OUT_DIR'],
+                        plot_type=plot_type, cmap=cmap,
+                        plot_step=plot_step)
 
 
 @main.command()
@@ -175,9 +201,9 @@ def reV_h5(ctx, h5_file, out_dir, sub_dir, dsets, group, process_size,
     if sub_dir is not None:
         qa_dir = os.path.join(out_dir, sub_dir)
 
-    QaQc.run(h5_file, qa_dir, dsets=dsets, group=group,
-             process_size=process_size, max_workers=max_workers,
-             plot_type=plot_type, cmap=cmap)
+    QaQc.h5(h5_file, qa_dir, dsets=dsets, group=group,
+            process_size=process_size, max_workers=max_workers,
+            plot_type=plot_type, cmap=cmap)
 
     if terminal:
         status = {'dirout': out_dir, 'job_status': 'successful',
@@ -202,7 +228,7 @@ def reV_h5(ctx, h5_file, out_dir, sub_dir, dsets, group, process_size,
 @click.option('--cmap', '-cmap', type=str, default='viridis',
               help="Colormap name, by default 'viridis'")
 @click.option('--lcoe', '-lcoe', type=STR, default='mean_lcoe',
-              help="LCOE value to plot, by default 'mean_lcoe'")
+              help="LCOE column label to plot, by default 'mean_lcoe'")
 @click.option('--log_file', '-log', type=click.Path(), default=None,
               help='File to log to, by default None')
 @click.option('-v', '--verbose', is_flag=True,
@@ -237,6 +263,72 @@ def supply_curve(ctx, sc_table, out_dir, sub_dir, columns, plot_type, cmap,
         Status.make_job_file(out_dir, 'qa-qc', name, status)
 
 
+@main.command()
+@click.option('--excl_fpath', '-excl', type=click.Path(exists=True),
+              required=True,
+              help='Exclusions file (.h5).')
+@click.option('--out_dir', '-o', type=click.Path(), required=True,
+              help="Project output directory path.")
+@click.option('--sub_dir', '-sd', type=STR, required=True,
+              help="Sub directory to save summary tables and plots too")
+@click.option('--excl_dict', '-exd', type=STR, default=None,
+              help='String representation of a dictionary of exclusions '
+              'LayerMask arguments {layer: {kwarg: value}} where layer is a '
+              'dataset in excl_fpath and kwarg can be "inclusion_range", '
+              '"exclude_values", "include_values", "use_as_weights", '
+              '"exclude_nodata", and/or "weight".')
+@click.option('--area_filter_kernel', '-afk', type=STR, default='queen',
+              help='Contiguous area filter kernel name ("queen", "rook").')
+@click.option('--min_area', '-ma', type=FLOAT, default=None,
+              help='Contiguous area filter minimum area, default is None '
+              '(No minimum area filter).')
+@click.option('--plot_type', '-plt', default='plotly',
+              type=click.Choice(['plot', 'plotly'], case_sensitive=False),
+              help=(" plot_type of plot to create 'plot' or 'plotly', by "
+                    "default 'plot'"))
+@click.option('--cmap', '-cmap', type=str, default='viridis',
+              help="Colormap name, by default 'viridis'")
+@click.option('--plot_step', '-step', type=int, default=100,
+              help="Step between points to plot")
+@click.option('--log_file', '-log', type=click.Path(), default=None,
+              help='File to log to, by default None')
+@click.option('-v', '--verbose', is_flag=True,
+              help='Flag to turn on debug logging.')
+@click.option('-t', '--terminal', is_flag=True,
+              help=('Flag for terminal QA pipeline call. '
+                    'Prints successful status file.'))
+@click.pass_context
+def exclusions(ctx, excl_fpath, out_dir, sub_dir, excl_dict,
+               area_filter_kernel, min_area, plot_type, cmap, plot_step,
+               log_file, verbose, terminal):
+    """
+    Extract and plot reV exclusions mask
+    """
+    name = ctx.obj['NAME']
+    if any([verbose, ctx.obj['VERBOSE']]):
+        log_level = 'DEBUG'
+    else:
+        log_level = 'INFO'
+
+    init_logger('reV.qa_qc', log_file=log_file, log_level=log_level)
+
+    qa_dir = out_dir
+    if sub_dir is not None:
+        qa_dir = os.path.join(out_dir, sub_dir)
+
+    if isinstance(excl_dict, str):
+        excl_dict = dict_str_load(excl_dict)
+
+    QaQc.exclusions_mask(excl_fpath, qa_dir, layers_dict=excl_dict,
+                         min_area=min_area, kernel=area_filter_kernel,
+                         plot_type=plot_type, cmap=cmap, plot_step=plot_step)
+
+    if terminal:
+        status = {'dirout': out_dir, 'job_status': 'successful',
+                  'finput': excl_fpath}
+        Status.make_job_file(out_dir, 'qa-qc', name, status)
+
+
 @main.command()
 @click.option('--config_file', '-c', required=True,
               type=click.Path(exists=True),
@@ -258,8 +350,7 @@ def from_config(ctx, config_file, verbose):
     ctx.obj['NAME'] = name
 
     # Enforce verbosity if logging level is specified in the config
-    if config.log_level == logging.DEBUG:
-        verbose = True
+    verbose = True if config.log_level == logging.DEBUG else False
 
     # initialize loggers
     init_mult(name, config.logdir, modules=[__name__, 'reV.config',
@@ -291,7 +382,26 @@ def from_config(ctx, config_file, verbose):
 
                 module_config = config.get_module_inputs(module)
                 fpath = module_config.fpath
-                if fpath.endswith('.h5'):
+                if module.lower() == 'exclusions':
+                    log_file = os.path.join(
+                        config.logdir,
+                        os.path.basename(fpath).replace('.h5', '.log'))
+                    afk = module_config.area_filter_kernel
+                    ctx.invoke(exclusions,
+                               excl_fpath=fpath,
+                               out_dir=config.dirout,
+                               sub_dir=module_config.sub_dir,
+                               excl_dict=module_config.excl_dict,
+                               area_filter_kernel=afk,
+                               min_area=module_config.min_area,
+                               plot_type=module_config.plot_type,
+                               cmap=module_config.cmap,
+                               plot_step=module_config.plot_step,
+                               log_file=log_file,
+                               verbose=verbose,
+                               terminal=terminal)
+
+                elif fpath.endswith('.h5'):
                     log_file = os.path.join(
                         config.logdir,
                         os.path.basename(fpath).replace('.h5', '.log'))
@@ -308,6 +418,7 @@ def from_config(ctx, config_file, verbose):
                                log_file=log_file,
                                verbose=verbose,
                                terminal=terminal)
+
                 elif fpath.endswith('.csv'):
                     log_file = os.path.join(
                         config.logdir,
@@ -410,6 +521,47 @@ def get_sc_cmd(name, sc_table, out_dir, sub_dir, columns, plot_type, cmap,
     return cmd
 
 
+def get_excl_cmd(name, excl_fpath, out_dir, sub_dir, excl_dict,
+                 area_filter_kernel, min_area, plot_type, cmap, plot_step,
+                 log_file, verbose, terminal):
+    """Build CLI call for exclusions."""
+
+    args = ('-excl {excl_fpath} '
+            '-o {out_dir} '
+            '-sd {sub_dir} '
+            '-exd {excl_dict} '
+            '-afk {area_filter_kernel} '
+            '-ma {min_area} '
+            '-plt {plot_type} '
+            '-cmap {cmap} '
+            '-step {plot_step} '
+            '-log {log_file} '
+            )
+
+    args = args.format(excl_fpath=SLURM.s(excl_fpath),
+                       out_dir=SLURM.s(out_dir),
+                       sub_dir=SLURM.s(sub_dir),
+                       excl_dict=SLURM.s(excl_dict),
+                       area_filter_kernel=SLURM.s(area_filter_kernel),
+                       min_area=SLURM.s(min_area),
+                       plot_type=SLURM.s(plot_type),
+                       cmap=SLURM.s(cmap),
+                       plot_step=SLURM.s(plot_step),
+                       log_file=SLURM.s(log_file),
+                       )
+
+    if verbose:
+        args += '-v '
+
+    if terminal:
+        args += '-t '
+
+    cmd = ('python -m reV.qa_qc.cli_qa_qc -n {} exclusions {}'
+           .format(SLURM.s(name), args))
+
+    return cmd
+
+
 def launch_slurm(config, verbose):
     """
     Launch slurm QA/QC job
@@ -430,14 +582,27 @@ def launch_slurm(config, verbose):
         module_config = config.get_module_inputs(module)
         fpaths = module_config.fpath
 
-        if isinstance(fpaths, str):
+        if isinstance(fpaths, (str, type(None))):
             fpaths = [fpaths]
 
         for j, fpath in enumerate(fpaths):
             if (i == len(config.module_names) - 1) and (j == len(fpaths) - 1):
                 terminal = True
-
-            if fpath.endswith('.h5'):
+            if module.lower() == 'exclusions':
+                node_cmd.append(get_excl_cmd(config.name,
+                                             module_config.excl_fpath,
+                                             out_dir,
+                                             module_config.sub_dir,
+                                             module_config.excl_dict,
+                                             module_config.area_filter_kernel,
+                                             module_config.min_area,
+                                             module_config.plot_type,
+                                             module_config.cmap,
+                                             module_config.plot_step,
+                                             log_file,
+                                             verbose,
+                                             terminal))
+            elif fpath.endswith('.h5'):
                 node_cmd.append(get_h5_cmd(config.name, fpath, out_dir,
                                            module_config.sub_dir,
                                            module_config.dsets,
