@@ -15,7 +15,7 @@ from rex.utilities.execution import SpawnProcessPool
 logger = logging.getLogger(__name__)
 
 
-class Summarize:
+class SummarizeH5:
     """
     reV Summary data for QA/QC
     """
@@ -110,68 +110,6 @@ class Summarize:
 
         return ds_summary
 
-    @staticmethod
-    def supply_curve_summary(sc_table, columns=None, out_path=None):
-        """
-        Summarize Supply Curve Table
-
-        Parameters
-        ----------
-        sc_table : str | pandas.DataFrame
-            Supply curve table or .csv containing table
-        columns : str | list, optional
-            Column(s) to summarize, if None summarize all numeric columns,
-            by default None
-        out_path : str, optional
-            Path to .csv to save summary to, by default None
-
-        Returns
-        -------
-        sc_summary : pandas.DataFrame
-            Summary statistics (mean, stdev, median, min, max, sum) for
-            Supply Curve table columns
-        """
-        sc_table = SummaryPlots._parse_summary(sc_table)
-        if columns is not None:
-            if isinstance(columns, str):
-                columns = [columns]
-
-            sc_table = sc_table[columns]
-
-        sc_table = sc_table.select_dtypes(include=np.number)
-
-        sc_summary = []
-        sc_stat = sc_table.mean(axis=0)
-        sc_stat.name = 'mean'
-        sc_summary.append(sc_stat)
-
-        sc_stat = sc_table.std(axis=0)
-        sc_stat.name = 'stdev'
-        sc_summary.append(sc_stat)
-
-        sc_stat = sc_table.median(axis=0)
-        sc_stat.name = 'median'
-        sc_summary.append(sc_stat)
-
-        sc_stat = sc_table.min(axis=0)
-        sc_stat.name = 'min'
-        sc_summary.append(sc_stat)
-
-        sc_stat = sc_table.max(axis=0)
-        sc_stat.name = 'max'
-        sc_summary.append(sc_stat)
-
-        sc_stat = sc_table.sum(axis=0)
-        sc_stat.name = 'sum'
-        sc_summary.append(sc_stat)
-
-        sc_summary = pd.concat(sc_summary, axis=1).T
-
-        if out_path is not None:
-            sc_summary.to_csv(out_path)
-
-        return sc_summary
-
     def summarize_dset(self, ds_name, process_size=None, max_workers=None,
                        out_path=None):
         """
@@ -325,63 +263,29 @@ class Summarize:
         out_path = os.path.join(out_dir, out_path)
         summary.summarize_means(out_path=out_path)
 
-    @classmethod
-    def supply_curve(cls, sc_table, out_dir, columns=None):
-        """
-        Summarize Supply Curve Table and save to disk
 
-        Parameters
-        ----------
-        sc_table : str | pandas.DataFrame
-            Path to .csv containing Supply Curve table
-        out_dir : str
-            Directory to dump summary .csv files to
-        columns : str | list, optional
-            Column(s) to summarize, if None summarize all numeric columns,
-            by default None
-        """
-        if not os.path.exists(out_dir):
-            os.makedirs(out_dir)
-
-        out_path = os.path.basename(sc_table).replace('.csv', '_summary.csv')
-        out_path = os.path.join(out_dir, out_path)
-        cls.supply_curve_summary(sc_table, columns=columns, out_path=out_path)
-
-
-class SummaryPlots:
+class SummarizeSupplyCurve:
     """
-    Plot summary data for QA/QC
+    Summarize Supply Curve table
     """
-    def __init__(self, summary):
-        """
-        Parameters
-        ----------
-        summary : str | pandas.DataFrame
-            Summary DataFrame or path to summary .csv
-        """
-        self._summary = self._parse_summary(summary)
+    def __init__(self, sc_table):
+        self._sc_table = self._parse_summary(sc_table)
+
+    def __repr__(self):
+        msg = "{}".format(self.__class__.__name__)
+
+        return msg
 
     @property
-    def summary(self):
+    def sc_table(self):
         """
-        Summary table
+        Supply Curve table
 
         Returns
         -------
-        pandas.DataFrame
+        pd.DataFrame
         """
-        return self._summary
-
-    @property
-    def columns(self):
-        """
-        Available columns in summary table
-
-        Returns
-        -------
-        list
-        """
-        return list(self._summary.columns)
+        return self._sc_table
 
     @staticmethod
     def _parse_summary(summary):
@@ -412,6 +316,120 @@ class SummaryPlots:
 
         return summary
 
+    def supply_curve_summary(self, columns=None, out_path=None):
+        """
+        Summarize Supply Curve Table
+
+        Parameters
+        ----------
+        sc_table : str | pandas.DataFrame
+            Supply curve table or .csv containing table
+        columns : str | list, optional
+            Column(s) to summarize, if None summarize all numeric columns,
+            by default None
+        out_path : str, optional
+            Path to .csv to save summary to, by default None
+
+        Returns
+        -------
+        sc_summary : pandas.DataFrame
+            Summary statistics (mean, stdev, median, min, max, sum) for
+            Supply Curve table columns
+        """
+        sc_table = self.sc_table
+        if columns is not None:
+            if isinstance(columns, str):
+                columns = [columns]
+
+            sc_table = sc_table[columns]
+
+        sc_table = sc_table.select_dtypes(include=np.number)
+
+        sc_summary = []
+        sc_stat = sc_table.mean(axis=0)
+        sc_stat.name = 'mean'
+        sc_summary.append(sc_stat)
+
+        sc_stat = sc_table.std(axis=0)
+        sc_stat.name = 'stdev'
+        sc_summary.append(sc_stat)
+
+        sc_stat = sc_table.median(axis=0)
+        sc_stat.name = 'median'
+        sc_summary.append(sc_stat)
+
+        sc_stat = sc_table.min(axis=0)
+        sc_stat.name = 'min'
+        sc_summary.append(sc_stat)
+
+        sc_stat = sc_table.max(axis=0)
+        sc_stat.name = 'max'
+        sc_summary.append(sc_stat)
+
+        sc_stat = sc_table.sum(axis=0)
+        sc_stat.name = 'sum'
+        sc_summary.append(sc_stat)
+
+        sc_summary = pd.concat(sc_summary, axis=1).T
+
+        if out_path is not None:
+            sc_summary.to_csv(out_path)
+
+        return sc_summary
+
+    @classmethod
+    def run(cls, sc_table, out_dir, columns=None):
+        """
+        Summarize Supply Curve Table and save to disk
+
+        Parameters
+        ----------
+        sc_table : str | pandas.DataFrame
+            Path to .csv containing Supply Curve table
+        out_dir : str
+            Directory to dump summary .csv files to
+        columns : str | list, optional
+            Column(s) to summarize, if None summarize all numeric columns,
+            by default None
+        """
+        if not os.path.exists(out_dir):
+            os.makedirs(out_dir)
+
+        summary = cls(sc_table)
+        out_path = os.path.basename(sc_table).replace('.csv', '_summary.csv')
+        out_path = os.path.join(out_dir, out_path)
+        summary.supply_curve_summary(columns=columns, out_path=out_path)
+
+
+class PlotBase:
+    """
+    QA/QC Plotting base class
+    """
+    def __init__(self, data):
+        """
+        Parameters
+        ----------
+        data : str | pandas.DataFrame | ndarray
+            data to plot or file containing data to plot
+        """
+        self._data = data
+
+    def __repr__(self):
+        msg = "{}".format(self.__class__.__name__)
+
+        return msg
+
+    @property
+    def data(self):
+        """
+        Data to plot
+
+        Returns
+        -------
+        pandas.DataFrame | ndarray
+        """
+        return self._data
+
     @staticmethod
     def _save_plotly(fig, out_path):
         """
@@ -429,12 +447,15 @@ class SummaryPlots:
         else:
             fig.write_image(out_path)
 
-    def _check_value(self, values, scatter=True):
+    @staticmethod
+    def _check_value(df, values, scatter=True):
         """
-        Check summary table for needed columns
+        Check DataFrame for needed columns
 
         Parameters
         ----------
+        df : pandas.DataFrame
+            DataFrame to check
         values : str | list
             Column(s) to plot
         scatter : bool, optional
@@ -447,12 +468,48 @@ class SummaryPlots:
             values += ['latitude', 'longitude']
 
         for value in values:
-            if value not in self.summary:
+            if value not in df:
                 msg = ("{} is not a valid column in summary table:\n{}"
-                       .format(value, self.columns))
+                       .format(value, df))
                 logger.error(msg)
                 raise ValueError(msg)
 
+
+class SummaryPlots(PlotBase):
+    """
+    Plot summary data for QA/QC
+    """
+    def __init__(self, summary):
+        """
+        Parameters
+        ----------
+        summary : str | pandas.DataFrame
+            Summary DataFrame or path to summary .csv
+        """
+        self._data = SummarizeSupplyCurve._parse_summary(summary)
+
+    @property
+    def summary(self):
+        """
+        Summary table
+
+        Returns
+        -------
+        pandas.DataFrame
+        """
+        return self._data
+
+    @property
+    def columns(self):
+        """
+        Available columns in summary table
+
+        Returns
+        -------
+        list
+        """
+        return list(self.summary.columns)
+
     def scatter_plot(self, value, cmap='viridis', out_path=None, **kwargs):
         """
         Plot scatter plot of value versus longitude and latitude using
@@ -469,7 +526,7 @@ class SummaryPlots:
         kwargs : dict
             Additional kwargs for plotting.dataframes.df_scatter
         """
-        self._check_value(value)
+        self._check_value(self.summary, value)
         mplt.df_scatter(self.summary, x='longitude', y='latitude', c=value,
                         colormap=cmap, filename=out_path, **kwargs)
 
@@ -490,7 +547,7 @@ class SummaryPlots:
         kwargs : dict
             Additional kwargs for plotly.express.scatter
         """
-        self._check_value(value)
+        self._check_value(self.summary, value)
         fig = px.scatter(self.summary, x='longitude', y='latitude',
                          color=value, color_continuous_scale=cmap, **kwargs)
         fig.update_layout(font=dict(family="Arial", size=18, color="black"))
@@ -515,52 +572,12 @@ class SummaryPlots:
             Supply curve data
         """
         values = ['capacity', lcoe]
-        self._check_value(values, scatter=False)
+        self._check_value(self.summary, values, scatter=False)
         sc_df = self.summary[values].sort_values(lcoe)
         sc_df['cumulative_capacity'] = sc_df['capacity'].cumsum()
 
         return sc_df
 
-    def supply_curve_plot(self, lcoe='mean_lcoe', out_path=None, **kwargs):
-        """
-        Plot supply curve (cumulative capacity vs lcoe) using seaborn.scatter
-
-        Parameters
-        ----------
-        lcoe : str, optional
-            LCOE value to plot, by default 'mean_lcoe'
-        out_path : str, optional
-            File path to save plot to, by default None
-        kwargs : dict
-            Additional kwargs for plotting.dataframes.df_scatter
-        """
-        sc_df = self._extract_sc_data(lcoe=lcoe)
-        mplt.df_scatter(sc_df, x='cumulative_capacity', y=lcoe,
-                        filename=out_path, **kwargs)
-
-    def supply_curve_plotly(self, lcoe='mean_lcoe', out_path=None, **kwargs):
-        """
-        Plot supply curve (cumulative capacity vs lcoe) using plotly
-
-        Parameters
-        ----------
-        lcoe : str, optional
-            LCOE value to plot, by default 'mean_lcoe'
-        out_path : str, optional
-            File path to save plot to, can be a .html or static image,
-            by default None
-        kwargs : dict
-            Additional kwargs for plotly.express.scatter
-        """
-        sc_df = self._extract_sc_data(lcoe=lcoe)
-        fig = px.scatter(sc_df, x='cumulative_capacity', y=lcoe, **kwargs)
-        fig.update_layout(font=dict(family="Arial", size=18, color="black"))
-
-        if out_path is not None:
-            self._save_plotly(fig, out_path)
-
-        fig.show()
-
     def dist_plot(self, value, out_path=None, **kwargs):
         """
         Plot distribution plot of value using seaborn.distplot
@@ -574,7 +591,7 @@ class SummaryPlots:
         kwargs : dict
             Additional kwargs for plotting.dataframes.dist_plot
         """
-        self._check_value(value, scatter=False)
+        self._check_value(self.summary, value, scatter=False)
         series = self.summary(value)
         mplt.dist_plot(series, filename=out_path, **kwargs)
 
@@ -591,7 +608,7 @@ class SummaryPlots:
         kwargs : dict
             Additional kwargs for plotly.express.histogram
         """
-        self._check_value(value, scatter=False)
+        self._check_value(self.summary, value, scatter=False)
 
         fig = px.histogram(self.summary, x=value)
 
@@ -660,7 +677,7 @@ class SummaryPlots:
             Additional plotting kwargs
         """
         splt = cls(summary_csv)
-        splt._summary = splt.summary.select_dtypes(include=np.number)
+        splt._data = splt.summary.select_dtypes(include=np.number)
         datasets = [c for c in splt.summary.columns
                     if not c.startswith(('lat', 'lon'))]
 
@@ -685,9 +702,107 @@ class SummaryPlots:
                 logger.error(msg)
                 raise ValueError(msg)
 
+
+class SupplyCurvePlot(PlotBase):
+    """
+    Plot supply curve data for QA/QC
+    """
+
+    def __init__(self, sc_table):
+        """
+        Parameters
+        ----------
+        sc_table : str | pandas.DataFrame
+            Supply curve table or path to supply curve .csv
+        """
+        self._data = SummarizeSupplyCurve._parse_summary(sc_table)
+
+    @property
+    def sc_table(self):
+        """
+        Supply curve table
+
+        Returns
+        -------
+        pandas.DataFrame
+        """
+        return self._data
+
+    @property
+    def columns(self):
+        """
+        Available columns in supply curve table
+
+        Returns
+        -------
+        list
+        """
+        return list(self.sc_table.columns)
+
+    def _extract_sc_data(self, lcoe='mean_lcoe'):
+        """
+        Extract supply curve data
+
+        Parameters
+        ----------
+        lcoe : str, optional
+            LCOE value to use for supply curve, by default 'mean_lcoe'
+
+        Returns
+        -------
+        sc_df : pandas.DataFrame
+            Supply curve data
+        """
+        values = ['capacity', lcoe]
+        self._check_value(self.sc_table, values, scatter=False)
+        sc_df = self.sc_table[values].sort_values(lcoe)
+        sc_df['cumulative_capacity'] = sc_df['capacity'].cumsum()
+
+        return sc_df
+
+    def supply_curve_plot(self, lcoe='mean_lcoe', out_path=None, **kwargs):
+        """
+        Plot supply curve (cumulative capacity vs lcoe) using seaborn.scatter
+
+        Parameters
+        ----------
+        lcoe : str, optional
+            LCOE value to plot, by default 'mean_lcoe'
+        out_path : str, optional
+            File path to save plot to, by default None
+        kwargs : dict
+            Additional kwargs for plotting.dataframes.df_scatter
+        """
+        sc_df = self._extract_sc_data(lcoe=lcoe)
+        mplt.df_scatter(sc_df, x='cumulative_capacity', y=lcoe,
+                        filename=out_path, **kwargs)
+
+    def supply_curve_plotly(self, lcoe='mean_lcoe', out_path=None, **kwargs):
+        """
+        Plot supply curve (cumulative capacity vs lcoe) using plotly
+
+        Parameters
+        ----------
+        lcoe : str, optional
+            LCOE value to plot, by default 'mean_lcoe'
+        out_path : str, optional
+            File path to save plot to, can be a .html or static image,
+            by default None
+        kwargs : dict
+            Additional kwargs for plotly.express.scatter
+        """
+        sc_df = self._extract_sc_data(lcoe=lcoe)
+        fig = px.scatter(sc_df, x='cumulative_capacity', y=lcoe, **kwargs)
+        fig.update_layout(font=dict(family="Arial", size=18, color="black"))
+
+        if out_path is not None:
+            self._save_plotly(fig, out_path)
+
+        fig.show()
+
     @classmethod
-    def supply_curve(cls, sc_table, out_dir, plot_type='plotly',
-                     lcoe='mean_lcoe', **kwargs):
+    def plot(cls, sc_table, out_dir, plot_type='plotly', lcoe='mean_lcoe',
+             **kwargs):
         """
         Create supply curve plot from supply curve table using lcoe value
         and save to out_dir
@@ -719,3 +834,139 @@ class SummaryPlots:
                    .format(plot_type))
             logger.error(msg)
             raise ValueError(msg)
+
+
+class ExclusionsMask(PlotBase):
+    """
+    Plot Exclusions mask as a heat map data for QA/QC
+    """
+
+    def __init__(self, excl_mask):
+        """
+        Parameters
+        ----------
+        excl_mask : str | ndarray
+            Exclusions mask or path to .npy file containing final mask
+        """
+        self._data = self._parse_mask(excl_mask)
+
+    @property
+    def mask(self):
+        """
+        Final Exclusions mask
+
+        Returns
+        -------
+        ndarray
+        """
+        return self._data
+
+    @staticmethod
+    def _parse_mask(excl_mask):
+        """
+        Load exclusions mask if needed
+
+        Parameters
+        ----------
+        excl_mask : str | ndarray
+            Exclusions mask or path to .npy file containing final mask
+
+        Returns
+        -------
+        excl_mask : ndarray
+            [n, m] array of final exclusion values
+        """
+        if isinstance(excl_mask, str):
+            excl_mask = np.load(excl_mask)
+        elif not isinstance(excl_mask, np.ndarray):
+            raise ValueError("excl_mask must be a .npy file or an ndarray")
+
+        return excl_mask
+
+    def exclusions_plot(self, cmap='Viridis', plot_step=100, out_path=None,
+                        **kwargs):
+        """
+        Plot exclusions mask as a seaborn heatmap
+
+        Parameters
+        ----------
+        cmap : str | px.color, optional
+            Continuous color scale to use, by default 'Viridis'
+        plot_step : int
+            Step between points to plot
+        out_path : str, optional
+            File path to save plot to, can be a .html or static image,
+            by default None
+        kwargs : dict
+            Additional kwargs for plotting.colormaps.heatmap_plot
+        """
+        mplt.heatmap_plot(self.mask[::plot_step, ::plot_step], cmap=cmap,
+                          filename=out_path, **kwargs)
+
+    def exclusions_plotly(self, cmap='Viridis', plot_step=100, out_path=None,
+                          **kwargs):
+        """
+        Plot exclusions mask as a plotly heatmap
+
+        Parameters
+        ----------
+        cmap : str | px.color, optional
+            Continuous color scale to use, by default 'Viridis'
+        plot_step : int
+            Step between points to plot
+        out_path : str, optional
+            File path to save plot to, can be a .html or static image,
+            by default None
+        kwargs : dict
+            Additional kwargs for plotly.express.imshow
+        """
+        fig = px.imshow(self.mask[::plot_step, ::plot_step],
+                        color_continuous_scale=cmap, **kwargs)
+        fig.update_layout(font=dict(family="Arial", size=18, color="black"))
+
+        if out_path is not None:
+            SummaryPlots._save_plotly(fig, out_path)
+
+        fig.show()
+
+    @classmethod
+    def plot(cls, mask, out_dir, plot_type='plotly', cmap='Viridis',
+             plot_step=100, **kwargs):
+        """
+        Plot exclusions mask and save to out_dir
+
+        Parameters
+        ----------
+        mask : ndarray
+            ndarray of final exclusions mask
+        out_dir : str
+            Output directory to save plots to
+        plot_type : str, optional
+            plot_type of plot to create 'plot' or 'plotly', by default 'plotly'
+        cmap : str, optional
+            Colormap name, by default 'viridis'
+        plot_step : int
+            Step between points to plot
+        kwargs : dict
+            Additional plotting kwargs
+        """
+        excl_mask = cls(mask)
+        if plot_type == 'plot':
+            out_path = 'exclusions_mask.png'
+            out_path = os.path.join(out_dir, out_path)
+            excl_mask.exclusions_plot(cmap=cmap.lower(),
+                                      plot_step=plot_step,
+                                      out_path=out_path,
+                                      **kwargs)
+        elif plot_type == 'plotly':
+            out_path = 'exclusions_mask.html'
+            out_path = os.path.join(out_dir, out_path)
+            excl_mask.exclusions_plotly(cmap=cmap.capitalize(),
+                                        plot_step=plot_step,
+                                        out_path=out_path,
+                                        **kwargs)
+        else:
+            msg = ("plot_type must be 'plot' or 'plotly' but {} was given"
+                   .format(plot_type))
+            logger.error(msg)
+            raise ValueError(msg)
